# djangoauthtoken
Django auth solution for Token creation/updation for a session.

### Run make migratons command:

```
python manage.py makemigrations djangoauthtoken
```

## Run command to migrate:

```
python manage.py migrate
```

## Run command to create superuser

```
python manage.py createsuperuser
```


Things to do:

- [X] Add api for Token.
- [X] Add api for login.
- [X] Add api for RefreshToken.
- [X] Add manager for create token.
- [X] Add serializer for user.
- [X] Add manager for create user.
- [X] Add api for user sign up.
- [] Add a custom command to delete invalid tokens.
- [] Add github Actions.
- [] Add pypi module push in this code base.


Twilio WebSocket Integration.
Django Twilio integration
Django web socket.
Django - React web socket.
Pypi push.
Django app install required modules.
Contact model.
Call log.
Contacts. API
Call Log API.
Whisper/Google speech integrate.